#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup


setup(name='fogg',
      version='0.1',
      description='fogg: cloud infrastructure',
      author=None,
      author_email='defn Nghiem <iam@defn.sh>',
      url=None,
      py_modules=['fogg'],
     )
